
# Update Term

## Term Name 

Command

## Summary
Commands are how a user of the Freddie markdown language requests an action.

## Status
DRAFT

## Description
Commands are how a user can request Egeria to take an action such as Create or Update an Egeria element. Freddie
provides
a limited (but growing) set of commands. Freddie commands align with the pyegeria 'hey-egeria' command line interface.

## Examples
Create Glossary or
Update Glossary or
Create Term or
Update Term

## Usage
Commands are used in the Freddie Egeria markdown language. updated

## Qualified Name
PDR:Term:Command

## Guid
9015183f-7357-43c8-859d-2006ae8b763e


---


---

# Update Term

## Term Name 

Source

## Summary
Source of the markdown content.

## Status
ACTIVE

## Description
Source of the markdown content - could be jupter or plain markdown file.

## Qualified Name
PDR:Term:Source

## Guid
55dcb682-2cd3-472f-8835-a14b1fcbd1c9


---


---

# Update Term

## Term Name 

Directive

## Summary
A directive defines how the command is to be processed.

## Status
DRAFT

## Description
Directives are one of:

* display - just display what we've found
* validate - check the validity of the requested action
* process - process the requested action

## Qualified Name
PDR:Term:Directive

## Guid
1ba5fafd-8424-438a-953c-9325fa5a080d

---

# Create Term

## Term Name 

Directive

## Summary
A directive defines how the command is to be processed.

## Status
DRAFT

## Description
A second description

## Qualified Name
PDR:Term:Directive2
